@@ -14,12 +14,9 @@ import shutil
 import uuid
 import subprocess as sp
 
-from ..base_calculator import Calculator
-from ..utilities import (
-    is_valid_xtb_solvent,
-    XTBInvalidSolventError,
-    XTBExtractor
-)
+from .calculators import Calculator
+from .results import XTBResults
+from ..utilities import is_valid_xtb_solvent, XTBInvalidSolventError
 
 logger = logging.getLogger(__name__)
 
@@ -28,13 +25,13 @@ class XTBEnergy(Calculator):
     """
     Uses GFN-xTB [1]_ to calculate energy and other properties.
 
-    By default, :meth:`get_energy` will extract other properties of the
-    :class:`.Molecule` passed to :meth:`get_energy`, which
-    will be saved in the attributes of :class:`.XTBEnergy`.
+    By default, :meth:`get_results` will extract other properties of
+    the :class:`.Molecule` passed to :meth:`calculate`, which
+    will be saved in the attributes of :class:`.XTBResults`.
 
     Notes
     -----
-    When running :meth:`get_energy`, this calculator changes the
+    When running :meth:`calculate`, this calculator changes the
     present working directory with :func:`os.chdir`. The original
     working directory will be restored even if an error is raised, so
     unless multi-threading is being used this implementation detail
@@ -47,53 +44,9 @@ class XTBEnergy(Calculator):
     Note that this does not have any impact on multi-processing,
     which should always be safe.
 
-    Attributes
-    ----------
-    total_energies : :class:`dict`
-        :class:`dict` of the total energy of each :class:`.Molecule`
-        passed to :meth:`get_energy`.
-
-    homo_lumo_gaps : :class:`dict`
-        :class:`dict` of the HOMO-LUMO gap of each :class:`.Molecule`
-        passed to :meth:`get_energy`.
-
-    fermi_levels : :class:`dict`
-        :class:`dict` of the Fermi level of each :class:`.Molecule`
-        passed to :meth:`get_energy`.
-
-    homo_lumo_orbitals : :class:`dict`
-        :class:`dict` of the HOMO-LUMO orbital properties of
-        each :class:`.Molecule` passed to :meth:`get_energy`.
-
-    qonly_dipole_moments : :class:`dict`
-        :class:`dict` of the q only dipole moment of
-        each :class:`.Molecule` passed to :meth:`get_energy`.
-
-    full_dipole_moments : :class:`dict`
-        :class:`dict` of the full dipole moment of
-        each :class:`.Molecule` passed to :meth:`get_energy`.
-
-    qonly_quadrupole_moments : :class:`dict`
-        :class:`dict` of the q only quadrupole moment of
-        each :class:`.Molecule` passed to :meth:`get_energy`.
-
-    qdip_quadrupole_moments : :class:`dict`
-        :class:`dict` of the q+dip quadrupole moment of
-        each :class:`.Molecule` passed to :meth:`get_energy`.
-
-    full_quadrupole_moments : :class:`dict`
-        :class:`dict` of the full quadrupole moment of
-        each :class:`.Molecule` passed to :meth:`get_energy`.
-
-    total_free_energies : :class:`dict`
-        :class:`dict` of the total free energy of
-        each :class:`.Molecule` passed to :meth:`get_energy`.
-        This is empty if :attr:`calculate_free_energy` is ``False``.
-
-    frequencies : :class:`dict`
-        :class:`dict` of the vibrational frequencies of
-        each :class:`.Molecule` passed to :meth:`get_energy`.
-        This is empty if `calculate_free_energy` was ``False``.
+    *Contributors*
+    We thank Andrew Tarzia and Alejandro Santana-Bonilla for their
+    contributions to this code.
 
     Examples
     --------
@@ -122,24 +75,20 @@ class XTBEnergy(Calculator):
         polymer = opt.optimize(polymer)
 
         # Calculate energy using GFN-xTB.
-        xtb = stk.XTBEnergy(
+        xtb = stko.XTBEnergy(
             xtb_path='/opt/gfnxtb/xtb',
             unlimited_memory=True
         )
 
-        p_total_energy = xtb.get_energy(polymer)
+        xtb_results = xtb.get_results(polymer)
 
         # Extract properties from the energy calculator for a given
         # molecule.
-        homo_lumo_gap = xtb.homo_lumo_gaps[polymer]
-        fermi_levels = xtb.fermi_levels[polymer]
-        homo_lumo_orbitals = xtb.homo_lumo_orbitals[polymer]
-        full_dipole_moments = xtb.full_dipole_moments[polymer]
-        full_quadrupole_moments = xtb.full_quadrupole_moments[polymer]
-
-        # The total energy can be extracted at any point from the
-        # calculator.
-        total_energy = xtb.total_energies[polymer]
+        total_energy = xtb_results.get_total_energy()
+        homo_lumo_gap = xtb_results.get_homo_lumo_gap()
+        fermi_levels = xtb_results.get_fermi_level()
+        homo_lumo_orbitals = xtb_results.get_homo_lumo_orbitals()
+        full_dipole_moments = xtb_results.get_full_dipole_moments()
 
     If `calculate_free_energy` is ``True``, xTB performs a
     numerical Hessian calculation and calculates the total free energy
@@ -150,9 +99,9 @@ class XTBEnergy(Calculator):
 
         # Optimize the constructed molecule so that it has a
         # reasonable structure.
-        optimizer = stk.OptimizerSequence(
-            stk.ETKDG(),
-            stk.XTB(
+        optimizer = stko.OptimizerSequence(
+            stko.ETKDG(),
+            stko.XTB(
                 xtb_path='/opt/gfnxtb/xtb',
                 unlimited_memory=True,
                 opt_level='verytight'
@@ -161,18 +110,18 @@ class XTBEnergy(Calculator):
         polymer = optimizer.optimize(polymer)
 
         # Calculate energy using GFN-xTB.
-        xtb = stk.XTBEnergy(
+        xtb = stko.XTBEnergy(
             xtb_path='/opt/gfnxtb/xtb',
             unlimited_memory=True,
             calculate_free_energy=True
         )
 
-        p_total_energy = xtb.get_energy(polymer)
+        xtb_results = xtb.get_results(polymer)
 
         # Extract properties from the energy calculator for a given
         # molecule.
-        p_total_free_energy = xtb.total_energies[polymer]
-        p_frequencies = xtb.frequencies[polymer]
+        total_free_energy = xtb_results.get_total_free_energy()
+        total_frequencies = xtb_results.get_frequencies()
 
     References
     ----------
@@ -252,7 +201,7 @@ class XTBEnergy(Calculator):
             solvent = solvent.lower()
             if gfn_version == 0:
                 raise XTBInvalidSolventError(
-                    f'No solvent valid for version',
+                    'No solvent valid for version',
                     f' {gfn_version!r}.'
                 )
             if not is_valid_xtb_solvent(gfn_version, solvent):
@@ -273,55 +222,7 @@ class XTBEnergy(Calculator):
         self._num_unpaired_electrons = str(num_unpaired_electrons)
         self._unlimited_memory = unlimited_memory
 
-        self.total_energies = {}
-        self.homo_lumo_gaps = {}
-        self.fermi_levels = {}
-        self.homo_lumo_orbitals = {}
-        self.qonly_dipole_moments = {}
-        self.full_dipole_moments = {}
-        self.qonly_quadrupole_moments = {}
-        self.qdip_quadrupole_moments = {}
-        self.full_quadrupole_moments = {}
-        self.total_free_energies = {}
-        self.frequencies = {}
-
-    def _get_properties(self, mol, output_file):
-        """
-        Extracts properties from a GFN-xTB energy calculation.
-
-        Parameters
-        ----------
-        mol : :class:`.Molecule`
-            The :class:`.Molecule` whose energy was calculated.
-
-        output_file : :class: `str`
-            Name of the output file with xTB results.
-
-        Returns
-        -------
-        None : :class:`NoneType`
-
-        """
-        # Get properties from output_file.
-        xtbext = XTBExtractor(output_file=output_file)
-
-        self.total_energies[mol] = xtbext.total_energy
-        self.homo_lumo_gaps[mol] = xtbext.homo_lumo_gap
-        self.fermi_levels[mol] = xtbext.fermi_level
-        self.homo_lumo_orbitals[mol] = xtbext.homo_lumo_occ
-        self.qonly_dipole_moments[mol] = xtbext.qonly_dipole_moment
-        self.full_dipole_moments[mol] = xtbext.full_dipole_moment
-        self.qonly_quadrupole_moments[mol] = \
-            xtbext.qonly_quadrupole_moment
-        self.qdip_quadrupole_moments[mol] = \
-            xtbext.qdip_quadrupole_moment
-        self.full_quadrupole_moments[mol] = \
-            xtbext.full_quadrupole_moment
-        if self._calculate_free_energy:
-            self.total_free_energies[mol] = xtbext.total_free_energy
-            self.frequencies[mol] = xtbext.frequencies
-
-    def _run_xtb(self, xyz, out_file):
+    def _run_xtb(self, xyz, out_file, init_dir, output_dir):
         """
         Runs GFN-xTB.
 
@@ -333,6 +234,13 @@ class XTBEnergy(Calculator):
         out_file : :class:`str`
             The name of output file with xTB results.
 
+        init_dir : :class:`str`
+            The name of the current working directory.
+
+        output_dir : :class:`str`
+            The name of the directory into which files generated during
+            the calculation are written.
+
         Returns
         -------
         None : :class:`NoneType`
@@ -366,17 +274,72 @@ class XTBEnergy(Calculator):
             f'--uhf {self._num_unpaired_electrons}'
         )
 
-        with open(out_file, 'w') as f:
-            # Note that sp.call will hold the program until completion
-            # of the calculation.
-            sp.call(
-                cmd,
-                stdin=sp.PIPE,
-                stdout=f,
-                stderr=sp.PIPE,
-                # Shell is required to run complex arguments.
-                shell=True
-            )
+        try:
+            os.chdir(output_dir)
+            with open(out_file, 'w') as f:
+                # Note that sp.call will hold the program until
+                # completion of the calculation.
+                sp.call(
+                    cmd,
+                    stdin=sp.PIPE,
+                    stdout=f,
+                    stderr=sp.PIPE,
+                    # Shell is required to run complex arguments.
+                    shell=True
+                )
+        finally:
+            os.chdir(init_dir)
+
+    def calculate(self, mol):
+        if self._output_dir is None:
+            output_dir = str(uuid.uuid4().int)
+        else:
+            output_dir = self._output_dir
+        output_dir = os.path.abspath(output_dir)
+
+        if os.path.exists(output_dir):
+            shutil.rmtree(output_dir)
+
+        os.mkdir(output_dir)
+        init_dir = os.getcwd()
+        xyz = os.path.join(output_dir, 'input_structure.xyz')
+        out_file = os.path.join(output_dir, 'energy.output')
+        mol.write(xyz)
+        yield self._run_xtb(
+            xyz=xyz,
+            out_file=out_file,
+            init_dir=init_dir,
+            output_dir=output_dir,
+        )
+
+    def get_results(self, mol):
+        """
+        Calculate the xTB properties of `mol`.
+
+        Parameters
+        ----------
+        mol : :class:`.Molecule`
+            The :class:`.Molecule` whose energy is to be calculated.
+
+        Returns
+        -------
+        :class:`.XTBResults`
+            The properties, with units, from xTB calculations.
+
+        """
+
+        if self._output_dir is None:
+            output_dir = str(uuid.uuid4().int)
+        else:
+            output_dir = self._output_dir
+        output_dir = os.path.abspath(output_dir)
+
+        out_file = os.path.join(output_dir, 'energy.output')
+
+        return XTBResults(
+            generator=self.calculate(mol),
+            output_file=out_file,
+        )
 
     def get_energy(self, mol):
         """
@@ -394,29 +357,4 @@ class XTBEnergy(Calculator):
 
         """
 
-        if self._output_dir is None:
-            output_dir = str(uuid.uuid4().int)
-        else:
-            output_dir = self._output_dir
-        output_dir = os.path.abspath(output_dir)
-
-        if os.path.exists(output_dir):
-            shutil.rmtree(output_dir)
-
-        os.mkdir(output_dir)
-        init_dir = os.getcwd()
-        xyz = os.path.join(output_dir, 'input_structure.xyz')
-        out_file = os.path.join(output_dir, 'energy.output')
-        mol.write(xyz)
-
-        try:
-            os.chdir(output_dir)
-            self._run_xtb(xyz=xyz, out_file=out_file)
-        finally:
-            os.chdir(init_dir)
-
-        self._get_properties(
-            mol=mol,
-            output_file=out_file
-        )
-        return self.total_energies[mol]
+        return self.get_results(mol).get_total_energy()[0]
