@@ -3,8 +3,9 @@ XTB Optimizers
 ==============
 
 #. :class:`.XTB`
+#. :class:`.XTBCREST`
 #. :class:`.XTBFF`
-#. :class:`.XTBFFMD`
+#. :class:`.XTBFFCREST`
 
 Wrappers for optimizers within the :mod:`xtb` code.
 
@@ -73,6 +74,10 @@ class XTB(Optimizer):
     The presence of negative frequencies can occur even when the
     optimization has converged based on the given `opt_level`.
 
+    *Contributors*
+    We thank Andrew Tarzia and Alejandro Santana-Bonilla for their
+    contributions to this code.
+
     Attributes
     ----------
     incomplete : :class:`set` of :class:`.Molecule`
@@ -258,7 +263,7 @@ class XTB(Optimizer):
             solvent = solvent.lower()
             if gfn_version == 0:
                 raise XTBInvalidSolventError(
-                    f'No solvent valid for version',
+                    'No solvent valid for version',
                     f' {gfn_version!r}.'
                 )
             if not is_valid_xtb_solvent(gfn_version, solvent):
@@ -706,7 +711,7 @@ class XTBCREST(Optimizer):
             solvent = solvent.lower()
             if gfn_version == 0:
                 raise XTBInvalidSolventError(
-                    f'No solvent valid for version',
+                    'No solvent valid for version',
                     f' {gfn_version!r}.'
                 )
             if not is_valid_xtb_solvent(gfn_version, solvent):
@@ -864,8 +869,8 @@ class XTBCREST(Optimizer):
 
         """
 
-        xyz = f'input_structure.xyz'
-        out_file = f'crest.output'
+        xyz = 'input_structure.xyz'
+        out_file = 'crest.output'
         mol.write(xyz)
         self._run_crest(xyz=xyz, out_file=out_file)
 
@@ -1130,8 +1135,8 @@ class XTBFF(Optimizer):
 
         """
 
-        xyz = f'input_structure_ff.xyz'
-        out_file = f'optimization_ff.output'
+        xyz = 'input_structure_ff.xyz'
+        out_file = 'optimization_ff.output'
         mol.write(xyz)
         self._run_xtb(xyz=xyz, out_file=out_file)
 
@@ -1496,8 +1501,8 @@ class XTBFFCREST(Optimizer):
 
         """
 
-        xyz = f'input_structure_ff.xyz'
-        out_file = f'crest_ff.output'
+        xyz = 'input_structure_ff.xyz'
+        out_file = 'crest_ff.output'
         mol.write(xyz)
         self._run_crest(xyz=xyz, out_file=out_file)
 
